==> jakarta-jmeter_2.3.4.orig.tar.gz: jakarta-jmeter-2.3.4/src/reports/org/apache/jmeter/report/gui/action/ReportEnableComponent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.jmeter.report.gui.action;

import java.awt.event.ActionEvent;
import java.util.HashSet;
import java.util.Set;

import org.apache.jmeter.gui.action.Command;
import org.apache.jmeter.gui.ReportGuiPackage;
import org.apache.jmeter.report.gui.tree.ReportTreeNode;
import org.apache.jorphan.logging.LoggingManager;
import org.apache.log.Logger;

public class ReportEnableComponent implements Command {
    private static final Logger log = LoggingManager.getLoggerForClass();

    public static final String ENABLE = "enable";

    public static final String DISABLE = "disable";

    private static final Set commands = new HashSet();
    static {
        commands.add(ENABLE);
        commands.add(DISABLE);
    }

    /**
     * @see org.apache.jmeter.gui.action.Command#doAction(ActionEvent)
     */
    public void doAction(ActionEvent e) {
        ReportTreeNode[] nodes = ReportGuiPackage.getInstance().getTreeListener().getSelectedNodes();

        if (e.getActionCommand().equals(ENABLE)) {
            log.debug("enabling currently selected gui objects");
            enableComponents(nodes, true);
        } else if (e.getActionCommand().equals(DISABLE)) {
            log.debug("disabling currently selected gui objects");
            enableComponents(nodes, false);
        }
    }

    private void enableComponents(ReportTreeNode[] nodes, boolean enable) {
        ReportGuiPackage pack = ReportGuiPackage.getInstance();
        for (int i = 0; i < nodes.length; i++) {
            nodes[i].setEnabled(enable);
            pack.getGui(nodes[i].getTestElement()).setEnabled(enable);
        }
    }

    /**
     * @see org.apache.jmeter.gui.action.Command#getActionNames()
     */
    public Set getActionNames() {
        return commands;
    }
}

==> jakarta-jmeter_2.5.1.orig.tar.gz: jakarta-jmeter-2.5.1/src/reports/org/apache/jmeter/report/gui/action/ReportEnableComponent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.jmeter.report.gui.action;

import java.awt.event.ActionEvent;
import java.util.HashSet;
import java.util.Set;

import org.apache.jmeter.gui.action.Command;
import org.apache.jmeter.gui.ReportGuiPackage;
import org.apache.jmeter.report.gui.tree.ReportTreeNode;
import org.apache.jorphan.logging.LoggingManager;
import org.apache.log.Logger;

public class ReportEnableComponent implements Command {
    private static final Logger log = LoggingManager.getLoggerForClass();

    public static final String ENABLE = "enable";

    public static final String DISABLE = "disable";

    private static final Set<String> commands = new HashSet<String>();
    static {
        commands.add(ENABLE);
        commands.add(DISABLE);
    }

    /**
     * @see org.apache.jmeter.gui.action.Command#doAction(ActionEvent)
     */
    public void doAction(ActionEvent e) {
        ReportTreeNode[] nodes = ReportGuiPackage.getInstance().getTreeListener().getSelectedNodes();

        if (e.getActionCommand().equals(ENABLE)) {
            log.debug("enabling currently selected gui objects");
            enableComponents(nodes, true);
        } else if (e.getActionCommand().equals(DISABLE)) {
            log.debug("disabling currently selected gui objects");
            enableComponents(nodes, false);
        }
    }

    private void enableComponents(ReportTreeNode[] nodes, boolean enable) {
        ReportGuiPackage pack = ReportGuiPackage.getInstance();
        for (int i = 0; i < nodes.length; i++) {
            nodes[i].setEnabled(enable);
            pack.getGui(nodes[i].getTestElement()).setEnabled(enable);
        }
    }

    /**
     * @see org.apache.jmeter.gui.action.Command#getActionNames()
     */
    public Set<String> getActionNames() {
        return commands;
    }
}
